@@ -23,21 +23,20 @@
     "redundant_projection",
     "RemoveRedundantBackticks",
     "ObjectPropertyName",
-    "deprecation"
+    "deprecation",
+    "detekt:all"
 )
 @file:org.gradle.api.Generated
 
-/* ktlint-disable */
-
 package org.gradle.kotlin.dsl
 
 
-           /**
-            * Kotlin extension function taking [kotlin.reflect.KClass] for [org.gradle.api.plugins.PluginManager.apply].
-            *
-            * @see org.gradle.api.plugins.PluginManager.apply
-* @since 2.3
-            */
+/**
+ * Kotlin extension function taking [kotlin.reflect.KClass] for [org.gradle.api.plugins.PluginManager.apply].
+ *
+ * @see org.gradle.api.plugins.PluginManager.apply
+ * @since 2.3
+ */
 inline fun org.gradle.api.plugins.PluginManager.`apply`(`type`: kotlin.reflect.KClass<*>): Unit =
     `apply`(`type`.java)
 
