@@ -23,21 +23,20 @@
     "redundant_projection",
     "RemoveRedundantBackticks",
     "ObjectPropertyName",
-    "deprecation"
+    "deprecation",
+    "detekt:all"
 )
 @file:org.gradle.api.Generated
 
-/* ktlint-disable */
-
 package org.gradle.kotlin.dsl
 
 
-           /**
-            * Kotlin extension function taking [kotlin.reflect.KClass] for [org.gradle.vcs.VcsMapping.from].
-            *
-            * @see org.gradle.vcs.VcsMapping.from
-* @since 4.4
-            */
+/**
+ * Kotlin extension function taking [kotlin.reflect.KClass] for [org.gradle.vcs.VcsMapping.from].
+ *
+ * @see org.gradle.vcs.VcsMapping.from
+ * @since 4.4
+ */
 inline fun <T : org.gradle.vcs.VersionControlSpec> org.gradle.vcs.VcsMapping.`from`(`type`: kotlin.reflect.KClass<T>, `configureAction`: org.gradle.api.Action<in T>): Unit =
     `from`(`type`.java, `configureAction`)
 
